@@ -2,7 +2,6 @@
 
 from .dto.action.action import Action
 from .dto.action.action_queue import ActionQueue
-from .dto.user.active import UserActive
 from .dto.user.event import UserEvent
 from .dto.user.feature import UserFeature
 from .dto.user.income import UserIncome
@@ -11,7 +10,6 @@ from .dto.user.population import UserPopulation
 from .dto.user.state import UserState
 from .dto.user.store import UserStore
 from .dto.user.user import User
-from .dto.world.status import WorldStatus
 from .feature_type import FeatureType
 from .store_type import StoreType
 from .user_event_other_type import UserEventOtherType
